from PyObjCTools.TestSupport import TestCase, min_os_level

import DeviceCheck


class TestDCAppAttestService(TestCase):
    @min_os_level("11.0")
    def test_methods(self):
        self.assertResultIsBOOL(DeviceCheck.DCAppAttestService.isSupported)

        self.assertArgIsBlock(
            DeviceCheck.DCAppAttestService.generateKeyWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            DeviceCheck.DCAppAttestService.attestKey_clientDataHash_completionHandler_,
            2,
            b"v@@",
        )
        self.assertArgIsBlock(
            DeviceCheck.DCAppAttestService.generateAssertion_clientDataHash_completionHandler_,
            2,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import DeviceCheck


class TestDCDevice(TestCase):
    @min_os_level("10.15")
    def test_methods(self):
        self.assertResultIsBOOL(DeviceCheck.DCDevice.isSupported)

        self.assertArgIsBlock(
            DeviceCheck.DCDevice.generateTokenWithCompletionHandler_, 0, b"v@@"
        )



from PyObjCTools.TestSupport import TestCase

import DeviceCheck


class TestDCError(TestCase):
    def test_constants(self):
        self.assertIsInstance(DeviceCheck.DCErrorDomain, str)

        self.assertEqual(DeviceCheck.DCErrorUnknownSystemFailure, 0)
        self.assertEqual(DeviceCheck.DCErrorFeatureUnsupported, 1)
        self.assertEqual(DeviceCheck.DCErrorInvalidInput, 2)
        self.assertEqual(DeviceCheck.DCErrorInvalidKey, 3)
        self.assertEqual(DeviceCheck.DCErrorServerUnavailable, 4)
